@@ -1,13 +1,16 @@
-"""$Id: pydbbdb.py,v 1.50 2008/12/21 10:54:21 rockyb Exp $
+"""$Id: pydbbdb.py,v 1.57 2009/03/06 09:41:37 rockyb Exp $
 Routines here have to do with the subclassing of bdb.  Defines Python
 debugger Basic Debugger (Bdb) class.  This file could/should probably
 get merged into bdb.py
 """
-import bdb, inspect, linecache, time, types
+import bdb, bytecode, inspect, linecache, time, types
 from repr import Repr
 from fns import *
 ## from complete import rl_complete
 
+def frame2file(obj, frame):
+    return obj.filename(obj.canonic_filename(frame))
+
 class Bdb(bdb.Bdb):
 
     # Additional levels call frames usually on the stack.
@@ -62,7 +65,7 @@ class Bdb(bdb.Bdb):
         if self.linetrace or (self.fntrace and include_fntrace):
             self.setup(frame)
             self.print_location(print_line=True)
-            self.display.displayAny(self.curframe)
+            self.display.display(self.curframe)
             if self.linetrace_delay:
                 time.sleep(self.linetrace_delay)
                 return
@@ -224,7 +227,7 @@ class Bdb(bdb.Bdb):
                                       self.main_dirname)
                 # Not if this is right for utter failure.
                 if not canonic: canonic = filename
-            canonic = os.path.normcase(canonic)
+            canonic = os.path.realpath(os.path.normcase(canonic))
             self.fncache[filename] = canonic
             return canonic
         return canonic
@@ -291,7 +294,7 @@ class Bdb(bdb.Bdb):
         """
         import repr as repr_mod
         frame, lineno = frame_lineno
-        filename = self.filename(self.canonic_filename(frame))
+        filename = frame2file(self, frame)
 
         s = ''
         if frame.f_code.co_name:
@@ -300,10 +303,22 @@ class Bdb(bdb.Bdb):
             s = "<lambda>"
 
         args, varargs, varkw, local_vars = inspect.getargvalues(frame)
-        parms=inspect.formatargvalues(args, varargs, varkw, local_vars)
-        if len(parms) >= self.maxargstrsize:
-            parms = "%s...)" % parms[0:self.maxargstrsize]
-        s += parms
+        if '<module>' == s and ([], None, None,) == (args, varargs, varkw,):
+            is_module = True
+            if is_exec_stmt(frame): 
+                s += ' exec()'
+            else:
+                fn_name = get_call_function_name(frame)
+                if fn_name: s += ' %s()' % fn_name
+                pass
+        else:
+            is_module = False
+            parms=inspect.formatargvalues(args, varargs, varkw, local_vars)
+            if len(parms) >= self.maxargstrsize:
+                parms = "%s...)" % parms[0:self.maxargstrsize]
+                pass
+            s += parms
+            pass
 
         # ddd can't handle wrapped stack entries.
         # if len(s) >= 35:
@@ -316,7 +331,9 @@ class Bdb(bdb.Bdb):
 
         add_quotes_around_file = True
         if include_location:
-            if s == '?()':
+            if is_module:
+                s += ' file'
+            elif s == '?()':
                 if is_exec_stmt(frame):
                     s = 'in exec'
                     exec_str = get_exec_string(frame.f_back)
@@ -433,7 +450,7 @@ class Bdb(bdb.Bdb):
         if self.stop_here(frame) or self.linetrace or self.fntrace:
             # Don't stop if we are looking at a def for which a breakpoint
             # has not been set.
-            filename = self.filename(self.canonic_filename(frame))
+            filename = frame2file(self, frame)
 
             # Python 2.5 or greater has 3 arg getline which handles
             # eggs and zip files
@@ -457,7 +474,7 @@ class Bdb(bdb.Bdb):
                 self.__print_location_if_trace(frame, False)
                 return
             if not self.break_here(frame):
-                if is_def_stmt(line, frame) and not self.deftrace:
+                if bytecode.is_def_stmt(line, frame) and not self.deftrace:
                     self.__print_location_if_trace(frame, False)
                     return
                 elif self.fntrace:
