@@ -6,7 +6,7 @@ not always) they are not specific to pydb. They are sort of more
 oriented towards any gdb-like debugger. Also routines that need to be
 changed from cmd are here.
 
-$Id: pydbcmd.py,v 1.51 2008/12/26 01:56:52 rockyb Exp $"""
+$Id: pydbcmd.py,v 1.57 2009/03/18 10:12:54 rockyb Exp $"""
 
 import cmd, linecache, sys, types
 from fns import *
@@ -34,6 +34,24 @@ class Cmd(cmd.Cmd):
         self.nohelp               = 'Undefined command or invalid expression \"%s\".\nType \"help\" for a list of debugger commands.'
         self.prompt               = '(Pydb) '
         self.rcLines              = []
+        return
+
+    def get_cmds(self):
+        '''Return a list of command names. These are the methods
+        that start do_'''
+        names = self.get_names()  # A list of all methods
+        names.sort()
+        # There can be duplicates if routines overridden. Weed these out.
+        prevname = ''; cmds = []
+        for name in names:
+            if name[:3] == 'do_':
+                if name == prevname:
+                    continue
+                prevname = name
+                cmds.append(name[3:])
+                pass
+            pass
+        return cmds
 
     def print_source_line(self, lineno, line):
         """Print out a source line of text , e.g. the second
@@ -51,6 +69,8 @@ class Cmd(cmd.Cmd):
         self.msg_nocr('%d %s' % (lineno, line))
         return
 
+
+
     def _runscript(self, filename):
         # When bdb sets tracing, a number of call and line events happens
         # BEFORE debugger even reaches user's code (and the exact sequence of
@@ -135,14 +155,14 @@ output.
 Some commands like 'info', 'set', and 'show' can accept an
 additional subcommand to give help just about that particular
 subcommand. For example 'help info line' give help about the
-\code{info line} command.
+'info line' command.
 
 See also 'examine' an 'whatis'.
         """
 
-        # We don't want to repeat the last help command. That makes
-        # not much sense and if give help that uses PAGER we may
-        # turn a quit CR into rerunning the help command.
+        # It does not make much sense to repeat the last help
+        # command. Also, given that 'help' uses PAGER, the you may
+        # enter an extra CR which would rerun the (long) help command.
         self.lastcmd='' 
 
         if arg:
@@ -429,6 +449,11 @@ See also 'examine' an 'whatis'.
         we give at least some place that's located in a file.      
         """
         i_stack = self.curindex
+
+        # Evaluation routines like "exec" don't show useful location
+        # info. In these cases, we will use the position before that in
+        # the stack.  Hence the looping below which in practices loops
+        # once and sometimes twice.
         while i_stack >= 0:
             frame_lineno = self.stack[i_stack]
             i_stack -= 1
@@ -442,6 +467,7 @@ See also 'examine' an 'whatis'.
                     break
             
             filename = self.filename(self.canonic_filename(frame))
+
             self.msg_nocr('(%s:%s):' % (filename, lineno))
             fn_name = frame.f_code.co_name
             if fn_name and fn_name != '?':
@@ -464,11 +490,12 @@ See also 'examine' an 'whatis'.
                 pass
             if line and len(line.strip()) != 0:
                 self.print_source_line(lineno, line)
+                pass
 
-            # If we are stopped at an "exec" or print the next outer
-            # location for that front-ends tracking source execution.
-            if not is_exec_stmt(frame):
+            if '<string>' != filename:
                 break
+            pass
+        return
 
     def onecmd(self, line):
 
@@ -571,4 +598,14 @@ See also 'examine' an 'whatis'.
         self.msg_nocr(ret)
         self.lastcmd = line
         return
+    pass
 
+if __name__ == '__main__':
+    class TestCmd(Cmd):
+        def do_a(self): return
+        def do_b(self): return
+        def do_a(self): return
+        pass
+    testcmd = TestCmd()
+    print testcmd.get_cmds()
+    pass
