@@ -2,7 +2,7 @@
 """Towers of Hanoi"""
 import sys, os
 
-top_builddir = "../"
+top_builddir = ".."
 if top_builddir[-1] != os.path.sep:
     top_builddir += os.path.sep
 sys.path.insert(0, os.path.join(top_builddir, 'pydb'))
